local mod = ...



-- Custom Component: Random Events -------------------------------------------------------------------------------------
local COMP_TAS_EVENT = {
	TypeName = "COMP_TAS_EVENT",
	ParentType = "COMPONENT",
	Properties = {
        {
            Name = "DayLastEvent",
            Type = "integer",
            Default = 0,
            Flags = { "SAVE_GAME" }
        },
		{
            Name = "EventTracker",
            Type = "list<vec2i>",
            Default = { 
                {1, 0},
                {2, 0},
                {3, 0},
                {4, 0},
                {5, 0},
                {6, 0},
                {7, 0},
                {8, 0},
                {9, 0},
                {10, 0},
                {11, 0},
                {12, 0},
                {13, 0},
                {14, 0},
                {15, 0},
                {16, 0},
                {17, 0},
                {18, 0},
                {19, 0},
                {20, 0},
                {21, 0},
                {22, 0},
                {23, 0},
                {24, 0},
                {25, 0},
                {26, 0},
                {27, 0},
                {28, 0},
                {29, 0},
                {30, 0},
            },
            Flags = { "SAVE_GAME" }
        },
    }
}



-- Register custom Class
mod:registerClass(COMP_TAS_EVENT)



-- Attach class to the prefab manager which means it will be present in the game from the beginning
mod:registerPrefabComponent("PREFAB_MANAGER", { DataType = "COMP_TAS_EVENT" } )



-- Loop through all events and create: Job, Quest, Event
for i=1, 22, 1 do

    -- Job: Event Trigger -------------------------------------------------------------------------------------
    mod:register({
        DataType = "JOB",
        Id = "JOB_TAS_EVENT_" .. string.sub("000" .. i, -3),
        JobName = "JOB_TAS_EVENT_NAME",
        JobDescription = "JOB_TAS_EVENT_DESC",
        IsLockedByDefault = true,
        Hidden = true,
        DefaultBehavior = "BEHAVIOR_WORK",
        ProductionDelay = 0.0, -- default 30
        AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
        CharacterSetup = {
            DataType = "CHARACTER_SETUP",
            IdleAnimation = "IDLE"
        }
    })

    mod:override({
        Id = "NEWCOMER",
        CompatibleJobList = {
            Action = "APPEND",
            "JOB_TAS_EVENT_" .. string.sub("000" .. i, -3)
        }
    })

    mod:override({
        Id = "SERF",
        CompatibleJobList = {
            Action = "APPEND",
            "JOB_TAS_EVENT_" .. string.sub("000" .. i, -3)
        }
    })

    mod:override({
        Id = "COMMONER",
        CompatibleJobList = {
            Action = "APPEND",
            "JOB_TAS_EVENT_" .. string.sub("000" .. i, -3)
        }
    })

    mod:override({
        Id = "CITIZEN",
        CompatibleJobList = {
            Action = "APPEND",
            "JOB_TAS_EVENT_" .. string.sub("000" .. i, -3)
        }
    })


    -- Quest ---------------------------------------------------------------------------------------------
    mod:register({
        DataType = "QUEST",
        Id = "QUEST_TAS_EVENT_" .. string.sub("000" .. i, -3),
        Name = "QUEST_TAS_EVENT_NAME",
        Description = "QUEST_TAS_EVENT_DESC",
        IsSilent = true,
        QuestFunction = {
            DataType = "QUEST_FUNCTION_ASSIGN_WORKER",
            Job = "JOB_TAS_EVENT_" .. string.sub("000" .. i, -3)
        },
        QuestRewardList = nil,
        QuestFailList = nil,
        QuestListToUnlockAfter = nil,
        OnFailCallback = nil,
        OnSuccessCallback = {
            DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
            Event = "EVENT_TAS_EVENT_" .. string.sub("000" .. i, -3)
        }
    })


    -- Default Balancing (event list) ---------------------------------------------------------------------------------------------
    mod:override({
        Id = "DEFAULT_BALANCING",
        EventList = {
            Action = "APPEND", 
            "EVENT_TAS_EVENT_SETUP_" .. string.sub("000" .. i, -3),
        },
    })


    -- Event: Setup ---------------------------------------------------------------------------------------------
    mod:register({
        DataType = "EVENT",
        Id = "EVENT_TAS_EVENT_SETUP_" .. string.sub("000" .. i, -3),
        Title = "EVENT_TAS_EVENT_SETUP_TITLE",
        Description = "EVENT_TAS_EVENT_SETUP_DESC",
        IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
        IsRecurrent = false,
        DaysToFirst = 1, -- number of days from the start of the game (setting = 5 will fire the event at the start of Day 5). 
        ConditionList = {
            {
                DataType = "EVENT_CONDITION_BUILDING_BUILT",
                AssetBuilding = "BUILDING_VILLAGE_CENTER"
            }
        },
        ActionList = {
            {
                DataType = "EVENT_ACTION_GIVE_QUEST",
                Quest = "QUEST_TAS_EVENT_" .. string.sub("000" .. i, -3)
            },
        }
    })

end

-- Quest 001: Troublesome Birds ----------------------------------------------------------------------------------------------
mod:override({
    Id = "QUEST_TAS_EVENT_001",
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_GAME_RULE",
            RuleModifier = {
                DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                ResourceList = {
                    "BERRIES",
                },
                YieldPercentage = 0.1,
                IsUntilRemoval = false, 
                IsGlobal = true, 
                DurationInDays = 28
            },
            OptionalApplicator = "EVENT_TAS_EVENT_SETUP_001"
        }
    }
})



-- Event: 001 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event001.png", "TEXTURE_TAS_EVENT001")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_001",
    Title = "EVENT_TAS_EVENT_001_TITLE",
	Description = "EVENT_TAS_EVENT_001_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_001_TITLE",
                Description = "EVENT_TAS_EVENT_001_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT001"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_001"
        },
    }
})

-- Quest 002: Orchards Infested ----------------------------------------------------------------------------------------------
mod:override({
    Id = "QUEST_TAS_EVENT_002",
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_GAME_RULE",
            RuleModifier = {
                DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                ResourceList = {
                    "RESOURCE_FRUIT",
                },
                YieldPercentage = 0.1,
                IsUntilRemoval = false, 
                IsGlobal = true, 
                DurationInDays = 28
            },
            OptionalApplicator = "EVENT_TAS_EVENT_SETUP_002"
        }
    }
})



-- Event: 002 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event002.png", "TEXTURE_TAS_EVENT002")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_002",
    Title = "EVENT_TAS_EVENT_002_TITLE",
	Description = "EVENT_TAS_EVENT_002_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_002_TITLE",
                Description = "EVENT_TAS_EVENT_002_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT002"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_002"
        },
    }
})



-- Event: 003 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event003.png", "TEXTURE_TAS_EVENT003")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_003",
    Title = "EVENT_TAS_EVENT_003_TITLE",
	Description = "EVENT_TAS_EVENT_003_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_003_TITLE",
                Description = "EVENT_TAS_EVENT_003_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT003"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_PAY",
            AmountToPay = {
                {
                    Resource = "WHEAT",
                    Quantity = 1000000
                },
                {
                    Resource = "FLOUR",
                    Quantity = 1000000
                },
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_003"
        },
    }
})



-- Event: 004 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event004.png", "TEXTURE_TAS_EVENT004")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_004",
    Title = "EVENT_TAS_EVENT_004_TITLE",
	Description = "EVENT_TAS_EVENT_004_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_004_TITLE",
                Description = "EVENT_TAS_EVENT_004_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT004"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_PAY",
            AmountToPay = {
                {
                    Resource = "CLOTHES",
                    Quantity = 1000000
                },
                {
                    Resource = "RESOURCE_FURNITURE",
                    Quantity = 1000000
                },
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_004"
        },
    }
})



-- Event: 005 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event005.png", "TEXTURE_TAS_EVENT005")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_005",
    Title = "EVENT_TAS_EVENT_005_TITLE",
	Description = "EVENT_TAS_EVENT_005_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_005_TITLE",
                Description = "EVENT_TAS_EVENT_005_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT005"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_005"
        },
    }
})

-- Quest 005: Guano ----------------------------------------------------------------------------------------------
mod:override({
    Id = "QUEST_TAS_EVENT_005",
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_GAME_RULE",
            RuleModifier = {
                DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                ResourceList = {
                    "RESOURCE_VEGETABLE",
                },
                YieldPercentage = 3.0,
                IsUntilRemoval = false, 
                IsGlobal = true, 
                DurationInDays = 56
            },
            OptionalApplicator = "EVENT_TAS_EVENT_SETUP_005"
        }
    }
})



-- Event: 006 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event006.png", "TEXTURE_TAS_EVENT006")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_006",
    Title = "EVENT_TAS_EVENT_006_TITLE",
	Description = "EVENT_TAS_EVENT_006_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_006_TITLE",
                Description = "EVENT_TAS_EVENT_006_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT006"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_006"
        },
    }
})

-- Quest 006: Blackfly ----------------------------------------------------------------------------------------------
mod:override({
    Id = "QUEST_TAS_EVENT_006",
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_GAME_RULE",
            RuleModifier = {
                DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                ResourceList = {
                    "RESOURCE_VEGETABLE",
                },
                YieldPercentage = 0.25,
                IsUntilRemoval = false, 
                IsGlobal = true, 
                DurationInDays = 28
            },
            OptionalApplicator = "EVENT_TAS_EVENT_SETUP_006"
        }
    }
})



-- Event: 007 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event007.png", "TEXTURE_TAS_EVENT007")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_007",
    Title = "EVENT_TAS_EVENT_007_TITLE",
	Description = "EVENT_TAS_EVENT_007_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_007_TITLE",
                Description = "EVENT_TAS_EVENT_007_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT007"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_007"
        },
    }
})

-- Quest 007: Flooding ----------------------------------------------------------------------------------------------
mod:override({
    Id = "QUEST_TAS_EVENT_007",
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_GAME_RULE",
            RuleModifier = {
                DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                ResourceList = {
                    "FISH",
                },
                YieldPercentage = 0.10,
                IsUntilRemoval = false, 
                IsGlobal = true, 
                DurationInDays = 28
            },
            OptionalApplicator = "EVENT_TAS_EVENT_SETUP_007"
        }
    }
})



-- Event: 008 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event008.png", "TEXTURE_TAS_EVENT008")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_008",
    Title = "EVENT_TAS_EVENT_008_TITLE",
	Description = "EVENT_TAS_EVENT_008_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_008_TITLE",
                Description = "EVENT_TAS_EVENT_008_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT008"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_008"
        },
    }
})

-- Quest 008: Foxes ----------------------------------------------------------------------------------------------
mod:override({
    Id = "QUEST_TAS_EVENT_008",
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_GAME_RULE",
            RuleModifier = {
                DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                ResourceList = {
                    "RESOURCE_POULTRY",
                    "BV1_EGG",
                },
                YieldPercentage = 0.50,
                IsUntilRemoval = false, 
                IsGlobal = true, 
                DurationInDays = 28
            },
            OptionalApplicator = "EVENT_TAS_EVENT_SETUP_008"
        }
    }
})



-- Event: 009 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event009.png", "TEXTURE_TAS_EVENT009")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_009",
    Title = "EVENT_TAS_EVENT_009_TITLE",
	Description = "EVENT_TAS_EVENT_009_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_009_TITLE",
                Description = "EVENT_TAS_EVENT_009_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT009"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_009"
        },
    }
})

-- Quest 009: Sour Milk ----------------------------------------------------------------------------------------------
mod:override({
    Id = "QUEST_TAS_EVENT_009",
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_GAME_RULE",
            RuleModifier = {
                DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                ResourceList = {
                    "MILK",
                },
                YieldPercentage = 0.25,
                IsUntilRemoval = false, 
                IsGlobal = true, 
                DurationInDays = 28
            },
            OptionalApplicator = "EVENT_TAS_EVENT_SETUP_009"
        }
    }
})



-- Event: 010 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event010.png", "TEXTURE_TAS_EVENT010")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_010",
    Title = "EVENT_TAS_EVENT_010_TITLE",
	Description = "EVENT_TAS_EVENT_010_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_010_TITLE",
                Description = "EVENT_TAS_EVENT_010_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT010"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_010"
        },
    }
})

-- Quest 010: Blown Away ----------------------------------------------------------------------------------------------
mod:override({
    Id = "QUEST_TAS_EVENT_010",
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_RESOURCES",
            ResourceCollection = {
                {
                    Resource = "WOOL",
                    Quantity = 100
                },
            }
        },
        {
            DataType = "QUEST_REWARD_GAME_RULE",
            RuleModifier = {
                DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                ResourceList = {
                    "WOOL",
                },
                YieldPercentage = 0.25,
                IsUntilRemoval = false, 
                IsGlobal = true, 
                DurationInDays = 28
            },
            OptionalApplicator = "EVENT_TAS_EVENT_SETUP_010"
        }
    }
})



-- Event: 011 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event011.png", "TEXTURE_TAS_EVENT011")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_011",
    Title = "EVENT_TAS_EVENT_011_TITLE",
	Description = "EVENT_TAS_EVENT_011_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_011_TITLE",
                Description = "EVENT_TAS_EVENT_011_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT011"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_011"
        },
    }
})

-- Quest 011: Murrain ----------------------------------------------------------------------------------------------
mod:override({
    Id = "QUEST_TAS_EVENT_011",
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_GAME_RULE",
            RuleModifier = {
                DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                ResourceList = {
                    "MILK",
                    "WOOL",
                    "RESOURCE_CATTLE",
                    "RESOURCE_PIG",
                    "RESOURCE_SHEEP",
                    "RESOURCE_GOAT",
                },
                YieldPercentage = 0.25,
                IsUntilRemoval = false, 
                IsGlobal = true, 
                DurationInDays = 56
            },
            OptionalApplicator = "EVENT_TAS_EVENT_SETUP_011"
        }
    }
})



-- Event: 012 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event012.png", "TEXTURE_TAS_EVENT012")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_012",
    Title = "EVENT_TAS_EVENT_012_TITLE",
	Description = "EVENT_TAS_EVENT_012_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_012_TITLE",
                Description = "EVENT_TAS_EVENT_012_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT012"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_012"
        },
    }
})

-- Quest 012: Priest Defrocked ----------------------------------------------------------------------------------------------
mod:override({
    Id = "QUEST_TAS_EVENT_012",
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_GAME_RULE",
            RuleModifier = {
                DataType = "GAME_RULE_MODIFIER_NEED_TYPE_DEPLETE_RATE",
                NeedType = "NEED_SERVICE",
                BonusInPerc = 4.0,
                IsUntilRemoval = false,
                IsGlobal = true,
                DurationInDays = 84
            },
            OptionalApplicator = "EVENT_TAS_EVENT_SETUP_012"
        },
    }
})



-- Event: 013 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event013.png", "TEXTURE_TAS_EVENT013")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_013",
    Title = "EVENT_TAS_EVENT_013_TITLE",
	Description = "EVENT_TAS_EVENT_013_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_013_TITLE",
                Description = "EVENT_TAS_EVENT_013_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT013"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_013"
        },
    }
})

-- Quest 013: Stern Sermon ----------------------------------------------------------------------------------------------
mod:override({
    Id = "QUEST_TAS_EVENT_013",
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_GAME_RULE",
            RuleModifier = {
                DataType = "GAME_RULE_MODIFIER_NEED_TYPE_DEPLETE_RATE",
                NeedType = "NEED_LUXURY",
                BonusInPerc = 4.0,
                IsUntilRemoval = false,
                IsGlobal = true,
                DurationInDays = 56
            },
            OptionalApplicator = "EVENT_TAS_EVENT_SETUP_013"
        },
    }
})



-- Event: 014 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event014.png", "TEXTURE_TAS_EVENT014")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_014",
    Title = "EVENT_TAS_EVENT_014_TITLE",
	Description = "EVENT_TAS_EVENT_014_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_014_TITLE",
                Description = "EVENT_TAS_EVENT_014_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT014"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_PAY",
            AmountToPay = {
                {
                    Resource = "GOLD_COINS",
                    Quantity = 1000
                },
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_014"
        },
    }
})



-- Event: 015 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event015.png", "TEXTURE_TAS_EVENT015")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_015",
    Title = "EVENT_TAS_EVENT_015_TITLE",
	Description = "EVENT_TAS_EVENT_015_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_015_TITLE",
                Description = "EVENT_TAS_EVENT_015_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT015"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_PAY",
            AmountToPay = {
                {
                    Resource = "GOLD_COINS",
                    Quantity = -2000
                },
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_015"
        },
    }
})



-- Event: 016 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event016.png", "TEXTURE_TAS_EVENT016")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_016",
    Title = "EVENT_TAS_EVENT_016_TITLE",
	Description = "EVENT_TAS_EVENT_016_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_016_TITLE",
                Description = "EVENT_TAS_EVENT_016_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT016"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_PAY",
            AmountToPay = {
                {
                    Resource = "GOLD_COINS",
                    Quantity = -1500
                },
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_016"
        },
    }
})

-- Quest 016: Shipwreck ----------------------------------------------------------------------------------------------
mod:override({
    Id = "QUEST_TAS_EVENT_016",
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_IMMIGRATION_WAVE"
        },
        {
            DataType = "QUEST_REWARD_IMMIGRATION_WAVE"
        },
    }
})



-- Event: 017 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event017.png", "TEXTURE_TAS_EVENT017")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_017",
    Title = "EVENT_TAS_EVENT_017_TITLE",
	Description = "EVENT_TAS_EVENT_017_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_017_TITLE",
                Description = "EVENT_TAS_EVENT_017_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT017"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_PAY",
            AmountToPay = {
                {
                    Resource = "GOLD_COINS",
                    Quantity = -250
                },
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_017"
        },
    }
})

-- Quest 017: Smugglers Caught ----------------------------------------------------------------------------------------------
mod:override({
    Id = "QUEST_TAS_EVENT_017",
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_RESOURCES",
            ResourceCollection = {
                {
                    Resource = "SWORD",
                    Quantity = 10
                },
                {
                    Resource = "SPEAR",
                    Quantity = 5
                },
                {
                    Resource = "JEWELRY",
                    Quantity = 20
                },
                {
                    Resource = "GEMS",
                    Quantity = 5
                },
            }
        },
    }
})



-- Event: 018 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event018.png", "TEXTURE_TAS_EVENT018")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_018",
    Title = "EVENT_TAS_EVENT_018_TITLE",
	Description = "EVENT_TAS_EVENT_018_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_018_TITLE",
                Description = "EVENT_TAS_EVENT_018_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT018"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_018_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_INFLUENCE",
                                    EstateInfluence = {
                                        Estate = "KINGDOM",
                                        Quantity = 10
                                    }
                                },
                                {
                                    DataType = "QUEST_REWARD_RESOURCES",
                                    ResourceCollection = {
                                        {
                                            Resource = "GOLD_COINS",
                                            Quantity = 500
                                        },
                                    }
                                },
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_018_CHOICE_2",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_RESOURCES",
                                    ResourceCollection = {
                                        {
                                            Resource = "GEMS",
                                            Quantity = 20
                                        },
                                    }
                                },
                                {
                                    DataType = "QUEST_REWARD_INFLUENCE",
                                    EstateInfluence = {
                                        Estate = "KINGDOM",
                                        Quantity = -20
                                    }
                                },
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_018"
        },
    }
})



-- Event: 019 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event019.png", "TEXTURE_TAS_EVENT019")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_019",
    Title = "EVENT_TAS_EVENT_019_TITLE",
	Description = "EVENT_TAS_EVENT_019_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_019_TITLE",
                Description = "EVENT_TAS_EVENT_019_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT019"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_019_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_PAY",
                            AmountToPay = {
                                {
                                    Resource = "GOLD_COINS",
                                    Quantity = 2500
                                },
                            }
                        },
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "FLOUR",
                                            "BREAD",
                                            "BEER",
                                            "WINE",
                                            "CHEESE",
                                            "WOOLEN_CLOTH",
                                            "CLOTHES",
                                            "TOOL",
                                            "IRON",
                                            "GLASS",
                                            "GOLD_BARS",
                                            "JEWELRY",
                                        },
                                        YieldPercentage = 0.795,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 28
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_019"
                                }
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_019_CHOICE_2",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "FLOUR",
                                            "BREAD",
                                            "BEER",
                                            "WINE",
                                            "CHEESE",
                                            "WOOLEN_CLOTH",
                                            "CLOTHES",
                                            "TOOL",
                                            "IRON",
                                            "GLASS",
                                            "GOLD_BARS",
                                            "JEWELRY",
                                        },
                                        YieldPercentage = 0.20,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 28
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_019"
                                }
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_019"
        },
    }
})



-- Event: 020 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event020.png", "TEXTURE_TAS_EVENT020")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_020",
    Title = "EVENT_TAS_EVENT_020_TITLE",
	Description = "EVENT_TAS_EVENT_020_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_020_TITLE",
                Description = "EVENT_TAS_EVENT_020_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT020"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_020_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "WHEAT",
                                            "MILK",
                                            "WOOL",
                                            "HOP",
                                            "RESOURCE_VEGETABLE",
                                            "RESOURCE_FRUIT",
                                            "RESOURCE_POULTRY",
                                            "BV1_EGG",
                                            "BV1_MEAT",
                                        },
                                        YieldPercentage = 0.795,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 28
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_020"
                                }
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_020_CHOICE_2",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_PAY",
                            AmountToPay = {
                                {
                                    Resource = "WHEAT",
                                    Quantity = 100
                                },
                                {
                                    Resource = "MILK",
                                    Quantity = 100
                                },
                                {
                                    Resource = "WOOL",
                                    Quantity = 100
                                },
                                {
                                    Resource = "HOP",
                                    Quantity = 100
                                },
                                {
                                    Resource = "RESOURCE_VEGETABLE",
                                    Quantity = 100
                                },
                                {
                                    Resource = "RESOURCE_FRUIT",
                                    Quantity = 100
                                },
                                {
                                    Resource = "RESOURCE_POULTRY",
                                    Quantity = 100
                                },
                                {
                                    Resource = "BV1_EGG",
                                    Quantity = 100
                                },
                                {
                                    Resource = "BV1_MEAT",
                                    Quantity = 100
                                },
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_020"
        },
    }
})



-- Event: 021 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event021.png", "TEXTURE_TAS_EVENT021")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_021",
    Title = "EVENT_TAS_EVENT_021_TITLE",
	Description = "EVENT_TAS_EVENT_021_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_021_TITLE",
                Description = "EVENT_TAS_EVENT_021_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT021"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_021_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_TERRITORY",
                                    Amount = 2
                                }
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_021_CHOICE_2",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_INFLUENCE",
                                    EstateInfluence = {
                                        Estate = "KINGDOM",
                                        Quantity = -20
                                    }
                                },
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_021"
        },
    }
})



-- Event: 022 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event022.png", "TEXTURE_TAS_EVENT022")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_022",
    Title = "EVENT_TAS_EVENT_022_TITLE",
	Description = "EVENT_TAS_EVENT_022_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_022_TITLE",
                Description = "EVENT_TAS_EVENT_022_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT022"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_022_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_IMMIGRATION_WAVE",
                                },
                                {
                                    DataType = "QUEST_REWARD_IMMIGRATION_WAVE",
                                },
                                {
                                    DataType = "QUEST_REWARD_IMMIGRATION_WAVE",
                                },
                                {
                                    DataType = "QUEST_REWARD_IMMIGRATION_WAVE",
                                },
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_IMMIGRATION_RATE",
                                        QuantityToAdd = 4,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 28
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_022"
                                }
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_022_CHOICE_2",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_INFLUENCE",
                                    EstateInfluence = {
                                        Estate = "LABOUR",
                                        Quantity = -20
                                    }
                                },
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_022"
        },
    }
})