local mod = ...


--[[

    Maxime edited my code and made it possible to show the Game Rules even after a reload. 
    Instead of using a quest to time between events, each event immediately fires the next one, but there is a delay:

                OnClickCallback = {
				DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
				Event = "EVENT_TAS_SEASON_SUMMER",
				Delay = _tasSeasonDays * 60

    For some reason this allows game rules to be displayed all the time, and they no longer have to cancel each other out.

]]--



-- Default Balancing (event list) ---------------------------------------------------------------------------------------------

mod:override({
    Id = "DEFAULT_BALANCING",
    EventList = {
        Action = "APPEND", 
        "EVENT_TAS_SEASON_SPRING",
    },
})



-- Disable the vanilla weather events by making their conditions impossible ------------------------------------------------------------------
mod:override({
    Id = "EVENT_BAD_WEATHER",
	ConditionList = {
        Action = "APPEND",
		{
            DataType = "GAME_CONDITION_MONTHLY_TRADE_REVENUE",
            MonthlyRevenue = 999999999
		}
	},
})

mod:override({
    Id = "EVENT_BAD_WEATHER_WARNING",
	ConditionList = {
        Action = "APPEND",
		{
            DataType = "GAME_CONDITION_MONTHLY_TRADE_REVENUE",
            MonthlyRevenue = 999999999
		}
	},
})



-- Variables ---------------------------------------------------------------------------------------------

_tasDaysUntilStart = 0 -- The day from zero on which to start the seasons
_tasYearDays = 336 -- Number of days in a full calendar year
_tasSeasonGap = 1 -- Number of days gap between seasons. Seems to be required for game rules to reset between instances
_tasSeasonDays = _tasYearDays / 4 -- Number of days in a full year, divided by four seasons
_tasSeasonDelay = 5.0 -- Number of seconds after the start of the day, to start each season's effects and pop up notification



-- Resource: Season (for display purposes) -------------------------------------------------------------------------------------
mod:registerAssetId("icons/Season.png", "ICON_SEASON")

mod:register({
	DataType = "RESOURCE",
	Id = "RESOURCE_SEASON",
	ResourceName = "RESOURCE_SEASON_NAME",
	Icon = "ICON_SEASON",
	ResourceTypeList = { "RESOURCE" },
    OrderId = 99,
	IsTradable = false,
    DisplayInInventory = false,
    DisplayInToolbar = true
})



-- Spring ---------------------------------------------------------------------------------------------

mod:registerAssetId("models/Textures/Spring.png", "TEXTURE_TAS_SPRING")

mod:register({
	DataType = "MATERIAL",
	Id = "MATERIAL_TAS_SPRING",
	HasAlphaTest = false,
	AlbedoTexture = "TEXTURE_TAS_SPRING"
})

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_SEASON_SPRING",
    Title = "EVENT_TAS_SEASON_SPRING_TITLE",
	Description = "EVENT_TAS_SEASON_SPRING_DESC",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = false,
    DaysToFirst = _tasDaysUntilStart, -- number of days from the start of the game (setting = 5 will fire the event at the start of Day 5). 
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_SEASON_SPRING_TITLE",
                Description = "EVENT_TAS_SEASON_SPRING_DESC",
                PanelVisual = "TEXTURE_TAS_SPRING"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        -- {
        --     DataType = "EVENT_ACTION_CHANGE_WEATHER",
        --     AssetWeather = "WEATHER_SUNNY",
        --     IsWeatherSystemOverriden = true,
        --     OnClickCallback = nil
        -- },
        {
            DataType = "EVENT_ACTION_GIVE_REWARD",
			OnClickCallback = {
				DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
				Event = "EVENT_TAS_SEASON_SUMMER",
				Delay = _tasSeasonDays * 60
			},
            QuestRewardList = {
                {
                    DataType = "QUEST_REWARD_GAME_RULE",
                    RuleModifier = {
                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                        ResourceList = {
                            "BERRIES",
                            "HONEY",
                            "RESOURCE_VEGETABLE",
                            "BOAR",
                            "WHEAT",
                            "HOP",
                            "GRAPES",
                            "RESOURCE_FRUIT",
                        },
                        YieldPercentage = 0.25,
                        IsUntilRemoval = false, 
                        IsGlobal = true, 
                        DurationInDays = _tasSeasonDays - _tasSeasonGap
                    },
                    OptionalApplicator = "EVENT_TAS_SEASON_SPRING"
                },
                {
                    DataType = "QUEST_REWARD_GAME_RULE",
                    RuleModifier = {
                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                        ResourceList = {
                            "MILK",
                            "HERBS",
                            "RESOURCE_CATTLE",
                            "RESOURCE_PIG",
                            "RESOURCE_GOAT",
                            "RESOURCE_SHEEP",
                            "RESOURCE_POULTRY",
                            "BV1_EGG",
                        },
                        YieldPercentage = 1.25,
                        IsUntilRemoval = false, 
                        IsGlobal = true,
                        DurationInDays = _tasSeasonDays - _tasSeasonGap
                    },
                    OptionalApplicator = "EVENT_TAS_SEASON_SPRING"
                },
            }
        },
        {
            DataType = "EVENT_ACTION_PAY",
            AmountToPay = {
                {
                    Resource = "RESOURCE_SEASON",
                    Quantity = 10
                }
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_REWARD",
            QuestRewardList = {
                {
                    DataType = "QUEST_REWARD_RESOURCES",
                    ResourceCollection = {
                        {
                            Resource = "RESOURCE_SEASON",
                            Quantity = 1
                        }
                    }
                },
            }
        },
        {
            DataType = "EVENT_ACTION_PAY",
            AmountToPay = {
                {
                    Resource = "RESOURCE_TEMPERATURE",
                    Quantity = 100
                }
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_REWARD",
            QuestRewardList = {
                {
                    DataType = "QUEST_REWARD_RESOURCES",
                    ResourceCollection = {
                        {
                            Resource = "RESOURCE_TEMPERATURE",
                            Quantity = 15
                        }
                    }
                },
            }
        },
    }
})



-- Summer ---------------------------------------------------------------------------------------------

mod:registerAssetId("models/Textures/Summer.png", "TEXTURE_TAS_SUMMER")

mod:register({
	DataType = "MATERIAL",
	Id = "MATERIAL_TAS_SUMMER",
	HasAlphaTest = false,
	AlbedoTexture = "TEXTURE_TAS_SUMMER"
})

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_SEASON_SUMMER",
    IsInMainPool = false,
    IsRecurrent = true,
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_SEASON_SUMMER_TITLE",
                Description = "EVENT_TAS_SEASON_SUMMER_DESC",
                PanelVisual = "TEXTURE_TAS_SUMMER"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                }
            },
            OnClickCallback = nil
        },
        -- {
        --     DataType = "EVENT_ACTION_CHANGE_WEATHER",
        --     AssetWeather = "WEATHER_SUNNY",
        --     IsWeatherSystemOverriden = true,
        --     OnClickCallback = nil
        -- },
        {
            DataType = "EVENT_ACTION_GIVE_REWARD",
			OnClickCallback = {
				DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
				Event = "EVENT_TAS_SEASON_AUTUMN",
				Delay = _tasSeasonDays * 60
			},
            QuestRewardList = {
                {
                    DataType = "QUEST_REWARD_GAME_RULE",
                    RuleModifier = {
                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                        ResourceList = {
                            "BOAR",
                        },
                        YieldPercentage = 0.25,
                        IsUntilRemoval = false,
                        IsGlobal = true, 
                        DurationInDays = _tasSeasonDays - _tasSeasonGap
                    },
                    OptionalApplicator = "EVENT_TAS_SEASON_SUMMER"
                }, 
                {
                    DataType = "QUEST_REWARD_GAME_RULE",
                    RuleModifier = {
                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                        ResourceList = {
                            "WHEAT",
                            "HOP",
                            "GRAPES",
                        },
                        YieldPercentage = 0.50,
                        IsUntilRemoval = false,
                        IsGlobal = true, 
                        DurationInDays = _tasSeasonDays - _tasSeasonGap
                    },
                    OptionalApplicator = "EVENT_TAS_SEASON_SUMMER"
                }, 
                {
                    DataType = "QUEST_REWARD_GAME_RULE",
                    RuleModifier = {
                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                        ResourceList = {
                            "BERRIES",
                            "MILK",
                            "HERBS",
                            "HONEY",
                            "RESOURCE_VEGETABLE",
                            "RESOURCE_POULTRY",
                            "BV1_EGG",
                            "RESOURCE_CATTLE",
                            "RESOURCE_PIG",
                            "RESOURCE_GOAT",
                            "RESOURCE_SHEEP",
                        },
                        YieldPercentage = 1.50,
                        IsUntilRemoval = false,
                        IsGlobal = true, 
                        DurationInDays = _tasSeasonDays - _tasSeasonGap
                    },
                    OptionalApplicator = "EVENT_TAS_SEASON_SUMMER"
                }, 
            },
        },
        {
            DataType = "EVENT_ACTION_PAY",
            AmountToPay = {
                {
                    Resource = "RESOURCE_SEASON",
                    Quantity = 10
                }
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_REWARD",
            QuestRewardList = {
                {
                    DataType = "QUEST_REWARD_RESOURCES",
                    ResourceCollection = {
                        {
                            Resource = "RESOURCE_SEASON",
                            Quantity = 2
                        }
                    }
                },
            }
        },
    }
})



-- Autumn ---------------------------------------------------------------------------------------------

mod:registerAssetId("models/Textures/Autumn.png", "TEXTURE_TAS_AUTUMN")

mod:register({
	DataType = "MATERIAL",
	Id = "MATERIAL_TAS_AUTUMN",
	HasAlphaTest = false,
	AlbedoTexture = "TEXTURE_TAS_AUTUMN"
})

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_SEASON_AUTUMN",
    IsInMainPool = false,
    IsRecurrent = true,
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_SEASON_AUTUMN_TITLE",
                Description = "EVENT_TAS_SEASON_AUTUMN_DESC",
                PanelVisual = "TEXTURE_TAS_AUTUMN"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                }
            },
            OnClickCallback = nil
        },
        -- {
        --     DataType = "EVENT_ACTION_CHANGE_WEATHER",
        --     AssetWeather = "WEATHER_SUNNY",
        --     IsWeatherSystemOverriden = true,
        --     OnClickCallback = nil
        -- },
        {
            DataType = "EVENT_ACTION_GIVE_REWARD",
			OnClickCallback = {
				DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
				Event = "EVENT_TAS_SEASON_WINTER",
				Delay = _tasSeasonDays * 60
			},
            QuestRewardList = {
                {
                    DataType = "QUEST_REWARD_GAME_RULE",
                    RuleModifier = {
                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                        ResourceList = {
                            "MILK",
                            "HERBS",
                            "RESOURCE_POULTRY",
                            "BV1_EGG",
                            "RESOURCE_CATTLE",
                            "RESOURCE_PIG",
                            "RESOURCE_GOAT",
                            "RESOURCE_SHEEP",
                        },
                        YieldPercentage = 0.25,
                        IsUntilRemoval = false,
                        IsGlobal = true, 
                        DurationInDays = _tasSeasonDays - _tasSeasonGap
                    },
                    OptionalApplicator = "EVENT_TAS_SEASON_AUTUMN"
                }, 
                {
                    DataType = "QUEST_REWARD_GAME_RULE",
                    RuleModifier = {
                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                        ResourceList = {
                            "BERRIES",
                            "HONEY",
                            "RESOURCE_VEGETABLE",
                            "WOOD",
                            "BOAR",
                        },
                        YieldPercentage = 1.25,
                        IsUntilRemoval = false,
                        IsGlobal = true, 
                        DurationInDays = _tasSeasonDays - _tasSeasonGap
                    },
                    OptionalApplicator = "EVENT_TAS_SEASON_AUTUMN"
                }, 
                {
                    DataType = "QUEST_REWARD_GAME_RULE",
                    RuleModifier = {
                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                        ResourceList = {
                            "WHEAT",
                            "HOP",
                            "GRAPES",
                        },
                        YieldPercentage = 1.50,
                        IsUntilRemoval = false,
                        IsGlobal = true, 
                        DurationInDays = _tasSeasonDays - _tasSeasonGap
                    },
                    OptionalApplicator = "EVENT_TAS_SEASON_AUTUMN"
                }, 
            }
        }, 
        {
            DataType = "EVENT_ACTION_PAY",
            AmountToPay = {
                {
                    Resource = "RESOURCE_SEASON",
                    Quantity = 10
                }
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_REWARD",
            QuestRewardList = {
                {
                    DataType = "QUEST_REWARD_RESOURCES",
                    ResourceCollection = {
                        {
                            Resource = "RESOURCE_SEASON",
                            Quantity = 3
                        }
                    }
                },
            }
        },
    }
})



-- Winter ---------------------------------------------------------------------------------------------

mod:registerAssetId("models/Textures/Winter.png", "TEXTURE_TAS_WINTER")

mod:register({
	DataType = "MATERIAL",
	Id = "MATERIAL_TAS_WINTER",
	HasAlphaTest = false,
	AlbedoTexture = "TEXTURE_TAS_WINTER"
})

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_SEASON_WINTER",
    IsInMainPool = false,
    IsRecurrent = true,
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_SEASON_WINTER_TITLE",
                Description = "EVENT_TAS_SEASON_WINTER_DESC",
                PanelVisual = "TEXTURE_TAS_WINTER"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                }
            },
            OnClickCallback = nil
        },
        -- {
        --     DataType = "EVENT_ACTION_CHANGE_WEATHER",
        --     AssetWeather = "WEATHER_RAINY",
        --     IsWeatherSystemOverriden = true,
        --     OnClickCallback = nil
        -- },
        {
            DataType = "EVENT_ACTION_GIVE_REWARD",
			OnClickCallback = {
				DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
				Event = "EVENT_TAS_SEASON_SPRING",
				Delay = _tasSeasonDays * 60
			},
            QuestRewardList = {
                {
                    DataType = "QUEST_REWARD_GAME_RULE",
                    RuleModifier = {
                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                        ResourceList = {
                            "BERRIES",
                            "MILK",
                            "HERBS",
                            "HONEY",
                            "RESOURCE_VEGETABLE",
                            "RESOURCE_POULTRY",
                            "BV1_EGG",
                            "RESOURCE_CATTLE",
                            "RESOURCE_PIG",
                            "RESOURCE_GOAT",
                            "RESOURCE_SHEEP",
                            "WHEAT",
                            "HOP",
                            "GRAPES",
                            "RESOURCE_FRUIT",
                        },
                        YieldPercentage = 0.25,
                        IsUntilRemoval = false,
                        IsGlobal = true, 
                        DurationInDays = _tasSeasonDays - _tasSeasonGap
                    },
                    OptionalApplicator = "EVENT_TAS_SEASON_WINTER"
                }, 
                {
                    DataType = "QUEST_REWARD_GAME_RULE",
                    RuleModifier = {
                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                        ResourceList = {
                            "WOOD",
                            "BOAR",
                        },
                        YieldPercentage = 1.50,
                        IsUntilRemoval = false,
                        IsGlobal = true, 
                        DurationInDays = _tasSeasonDays - _tasSeasonGap
                    },
                    OptionalApplicator = "EVENT_TAS_SEASON_WINTER"
                }, 
            }
        },
        {
            DataType = "EVENT_ACTION_PAY",
            AmountToPay = {
                {
                    Resource = "RESOURCE_SEASON",
                    Quantity = 10
                }
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_REWARD",
            QuestRewardList = {
                {
                    DataType = "QUEST_REWARD_RESOURCES",
                    ResourceCollection = {
                        {
                            Resource = "RESOURCE_SEASON",
                            Quantity = 4
                        }
                    }
                },
            }
        },
    }
})


